recsyslearn.beyond\_accuracy package
====================================

Submodules
----------

recsyslearn.beyond\_accuracy.metrics module
-------------------------------------------

.. automodule:: recsyslearn.beyond_accuracy.metrics
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: recsyslearn.beyond_accuracy
   :members:
   :undoc-members:
   :show-inheritance:
